HGVS Railroad Diagram
^^^^^^^^^^^^^^^^^^^^^

  | Generated from `hgvs (https://bitbucket.org/invitae/hgvs/) <https://bitbucket.org/invitae/hgvs/>`_
  | c1a058136af7+ default tip
  | See the source code for the OMeta-based grammar

Variants
~~~~~~~~
.. image:: hgvs_railroad/any_variant.svg
  :align: center
.. image:: hgvs_railroad/c_variant.svg
  :align: center
.. image:: hgvs_railroad/gmn_variant.svg
  :align: center
.. image:: hgvs_railroad/g_variant.svg
  :align: center
.. image:: hgvs_railroad/hgvs_variant.svg
  :align: center
.. image:: hgvs_railroad/m_variant.svg
  :align: center
.. image:: hgvs_railroad/n_variant.svg
  :align: center
.. image:: hgvs_railroad/p_variant.svg
  :align: center
.. image:: hgvs_railroad/r_variant.svg
  :align: center


Intervals
~~~~~~~~~
.. image:: hgvs_railroad/c_interval.svg
  :align: center
.. image:: hgvs_railroad/def_c_interval.svg
  :align: center
.. image:: hgvs_railroad/def_g_interval.svg
  :align: center
.. image:: hgvs_railroad/def_gmn_interval.svg
  :align: center
.. image:: hgvs_railroad/def_m_interval.svg
  :align: center
.. image:: hgvs_railroad/def_n_interval.svg
  :align: center
.. image:: hgvs_railroad/def_p_interval.svg
  :align: center
.. image:: hgvs_railroad/def_r_interval.svg
  :align: center
.. image:: hgvs_railroad/g_interval.svg
  :align: center
.. image:: hgvs_railroad/gmn_interval.svg
  :align: center
.. image:: hgvs_railroad/m_interval.svg
  :align: center
.. image:: hgvs_railroad/n_interval.svg
  :align: center
.. image:: hgvs_railroad/p_interval.svg
  :align: center
.. image:: hgvs_railroad/r_interval.svg
  :align: center


Localized Edits
~~~~~~~~~~~~~~~
.. image:: hgvs_railroad/c_posedit.svg
  :align: center
.. image:: hgvs_railroad/gmn_posedit.svg
  :align: center
.. image:: hgvs_railroad/g_posedit.svg
  :align: center
.. image:: hgvs_railroad/m_posedit.svg
  :align: center
.. image:: hgvs_railroad/n_posedit.svg
  :align: center
.. image:: hgvs_railroad/p_posedit_special.svg
  :align: center
.. image:: hgvs_railroad/p_posedit.svg
  :align: center
.. image:: hgvs_railroad/r_posedit.svg
  :align: center


Positions
~~~~~~~~~
.. image:: hgvs_railroad/c_hgvs_position.svg
  :align: center
.. image:: hgvs_railroad/c_pos.svg
  :align: center
.. image:: hgvs_railroad/def_c_pos.svg
  :align: center
.. image:: hgvs_railroad/def_gmn_pos.svg
  :align: center
.. image:: hgvs_railroad/def_g_pos.svg
  :align: center
.. image:: hgvs_railroad/def_m_pos.svg
  :align: center
.. image:: hgvs_railroad/def_n_pos.svg
  :align: center
.. image:: hgvs_railroad/def_p_pos.svg
  :align: center
.. image:: hgvs_railroad/def_r_pos.svg
  :align: center
.. image:: hgvs_railroad/g_hgvs_position.svg
  :align: center
.. image:: hgvs_railroad/gmn_hgvs_position.svg
  :align: center
.. image:: hgvs_railroad/gmn_pos.svg
  :align: center
.. image:: hgvs_railroad/g_pos.svg
  :align: center
.. image:: hgvs_railroad/hgvs_position.svg
  :align: center
.. image:: hgvs_railroad/m_hgvs_position.svg
  :align: center
.. image:: hgvs_railroad/m_pos.svg
  :align: center
.. image:: hgvs_railroad/n_hgvs_position.svg
  :align: center
.. image:: hgvs_railroad/n_pos.svg
  :align: center
.. image:: hgvs_railroad/p_hgvs_position.svg
  :align: center
.. image:: hgvs_railroad/p_pos.svg
  :align: center
.. image:: hgvs_railroad/r_hgvs_position.svg
  :align: center
.. image:: hgvs_railroad/r_pos.svg
  :align: center


Edits (sequence changes)
~~~~~~~~~~~~~~~~~~~~~~~~
.. image:: hgvs_railroad/c_edit.svg
  :align: center
.. image:: hgvs_railroad/dna_delins.svg
  :align: center
.. image:: hgvs_railroad/dna_del.svg
  :align: center
.. image:: hgvs_railroad/dna_dup.svg
  :align: center
.. image:: hgvs_railroad/dna_edit_mu.svg
  :align: center
.. image:: hgvs_railroad/dna_edit.svg
  :align: center
.. image:: hgvs_railroad/dna_ins.svg
  :align: center
.. image:: hgvs_railroad/dna_subst.svg
  :align: center
.. image:: hgvs_railroad/g_edit.svg
  :align: center
.. image:: hgvs_railroad/gmn_edit.svg
  :align: center
.. image:: hgvs_railroad/m_edit.svg
  :align: center
.. image:: hgvs_railroad/n_edit.svg
  :align: center
.. image:: hgvs_railroad/p_edit.svg
  :align: center
.. image:: hgvs_railroad/pro_delins.svg
  :align: center
.. image:: hgvs_railroad/pro_del.svg
  :align: center
.. image:: hgvs_railroad/pro_dup.svg
  :align: center
.. image:: hgvs_railroad/pro_edit_mu.svg
  :align: center
.. image:: hgvs_railroad/pro_edit.svg
  :align: center
.. image:: hgvs_railroad/pro_ins.svg
  :align: center
.. image:: hgvs_railroad/pro_subst.svg
  :align: center
.. image:: hgvs_railroad/r_edit.svg
  :align: center
.. image:: hgvs_railroad/rna_delins.svg
  :align: center
.. image:: hgvs_railroad/rna_del.svg
  :align: center
.. image:: hgvs_railroad/rna_dup.svg
  :align: center
.. image:: hgvs_railroad/rna_edit_mu.svg
  :align: center
.. image:: hgvs_railroad/rna_edit.svg
  :align: center
.. image:: hgvs_railroad/rna_ins.svg
  :align: center
.. image:: hgvs_railroad/rna_subst.svg
  :align: center


Sequences
~~~~~~~~~
.. image:: hgvs_railroad/aa13_seq.svg
  :align: center
.. image:: hgvs_railroad/aa1_seq.svg
  :align: center
.. image:: hgvs_railroad/aa3_seq.svg
  :align: center
.. image:: hgvs_railroad/aat13_seq.svg
  :align: center
.. image:: hgvs_railroad/aat1_seq.svg
  :align: center
.. image:: hgvs_railroad/aat3_seq.svg
  :align: center
.. image:: hgvs_railroad/dna_seq.svg
  :align: center
.. image:: hgvs_railroad/rna_seq.svg
  :align: center


Residues
~~~~~~~~
.. image:: hgvs_railroad/aa13_ext.svg
  :align: center
.. image:: hgvs_railroad/aa13_fs.svg
  :align: center
.. image:: hgvs_railroad/aa13.svg
  :align: center
.. image:: hgvs_railroad/aa1.svg
  :align: center
.. image:: hgvs_railroad/aa3.svg
  :align: center
.. image:: hgvs_railroad/aat13.svg
  :align: center
.. image:: hgvs_railroad/aat1.svg
  :align: center
.. image:: hgvs_railroad/aat3.svg
  :align: center
.. image:: hgvs_railroad/dna.svg
  :align: center
.. image:: hgvs_railroad/rna.svg
  :align: center


Remaining rules
~~~~~~~~~~~~~~~
.. image:: hgvs_railroad/accn.svg
  :align: center
.. image:: hgvs_railroad/base.svg
  :align: center
.. image:: hgvs_railroad/gmn_type.svg
  :align: center
.. image:: hgvs_railroad/Not_Yet_Implemented.svg
  :align: center
.. image:: hgvs_railroad/num.svg
  :align: center
.. image:: hgvs_railroad/offset.svg
  :align: center
.. image:: hgvs_railroad/pm.svg
  :align: center
.. image:: hgvs_railroad/snum.svg
  :align: center
.. image:: hgvs_railroad/term13.svg
  :align: center
.. image:: hgvs_railroad/term1.svg
  :align: center
.. image:: hgvs_railroad/term3.svg
  :align: center


